==> ant-design-vue-4.0.0.jar: META-INF/resources/webjars/ant-design-vue/4.0.0/lib/vc-progress/src/Circle.d.ts <==
import type { GapPositionType } from './types';
declare const _default: import("vue").DefineComponent<{
    gapDegree: NumberConstructor;
    gapPosition: {
        type: import("vue").PropType<GapPositionType>;
    };
    percent: {
        type: import("vue").PropType<number | number[]>;
    };
    prefixCls: StringConstructor;
    strokeColor: {
        type: import("vue").PropType<import("./types").StrokeColorType>;
    };
    strokeLinecap: {
        type: import("vue").PropType<import("./types").StrokeLinecapType>;
    };
    strokeWidth: NumberConstructor;
    trailColor: StringConstructor;
    trailWidth: NumberConstructor;
    transition: StringConstructor;
}, () => JSX.Element, unknown, {}, {}, import("vue").ComponentOptionsMixin, import("vue").ComponentOptionsMixin, {}, string, import("vue").VNodeProps & import("vue").AllowedComponentProps & import("vue").ComponentCustomProps, Readonly<import("vue").ExtractPropTypes<{
    gapDegree: NumberConstructor;
    gapPosition: {
        type: import("vue").PropType<GapPositionType>;
    };
    percent: {
        type: import("vue").PropType<number | number[]>;
    };
    prefixCls: StringConstructor;
    strokeColor: {
        type: import("vue").PropType<import("./types").StrokeColorType>;
    };
    strokeLinecap: {
        type: import("vue").PropType<import("./types").StrokeLinecapType>;
    };
    strokeWidth: NumberConstructor;
    trailColor: StringConstructor;
    trailWidth: NumberConstructor;
    transition: StringConstructor;
}>>, {}, {}>;
export default _default;

==> ant-design-vue-4.2.5.jar: META-INF/resources/webjars/ant-design-vue/4.2.5/lib/vc-progress/src/Circle.d.ts <==
import type { GapPositionType } from './types';
declare const _default: import("vue").DefineComponent<{
    gapDegree: NumberConstructor;
    gapPosition: {
        type: import("vue").PropType<GapPositionType>;
    };
    percent: {
        type: import("vue").PropType<number | number[]>;
    };
    prefixCls: StringConstructor;
    strokeColor: {
        type: import("vue").PropType<import("./types").StrokeColorType>;
    };
    strokeLinecap: {
        type: import("vue").PropType<import("./types").StrokeLinecapType>;
    };
    strokeWidth: NumberConstructor;
    trailColor: StringConstructor;
    trailWidth: NumberConstructor;
    transition: StringConstructor;
}, () => import("vue/jsx-runtime").JSX.Element, unknown, {}, {}, import("vue").ComponentOptionsMixin, import("vue").ComponentOptionsMixin, {}, string, import("vue").PublicProps, Readonly<import("vue").ExtractPropTypes<{
    gapDegree: NumberConstructor;
    gapPosition: {
        type: import("vue").PropType<GapPositionType>;
    };
    percent: {
        type: import("vue").PropType<number | number[]>;
    };
    prefixCls: StringConstructor;
    strokeColor: {
        type: import("vue").PropType<import("./types").StrokeColorType>;
    };
    strokeLinecap: {
        type: import("vue").PropType<import("./types").StrokeLinecapType>;
    };
    strokeWidth: NumberConstructor;
    trailColor: StringConstructor;
    trailWidth: NumberConstructor;
    transition: StringConstructor;
}>>, {}, {}>;
export default _default;
